@@ -9,6 +9,7 @@ from sys import stderr
 from typing import TYPE_CHECKING, Callable, Coroutine, Iterator, Type
 
 from aiostream import stream
+from aiostream.core import StreamEmpty
 from ranges import Range, RangeSet
 
 MYPY = False  # when using mypy will be overrided as True
@@ -89,7 +90,15 @@ class AsyncFetcher:
         urlset = (u for u in self.filtered_url_list)  # single use URL generator
         if self.show_progress_bar:
             self.set_up_progress_bar()
-        self.fetch_things(urls=urlset)
+        try:
+            self.fetch_things(urls=urlset)
+        except StreamEmpty as exc:
+            # Treat this like a StopIteration (was called despite completed URLs)
+            if self.close_client_on_completion:
+                asyncio.run(self.client.aclose())
+            else:
+                raise
+            # Note: to avoid throwing exception, check `total_complete` before calling
         if self.show_progress_bar:
             self.pbar.close()
 
@@ -112,8 +121,12 @@ class AsyncFetcher:
             log.debug(f"Processed URL in async callback: {source_url}")
         if self.show_progress_bar:
             self.pbar.update()
-        self.complete_row(row_index=i)
+        if i not in self.completed:
+            # Don't bother putting in if already been marked as complete in the callback
+            self.complete_row(row_index=i)
         await resp.aclose()
+        if self.total_complete == self.n and self.close_client_on_completion:
+            await self.client.aclose()
 
     @property
     def total_complete(self) -> int:
@@ -210,8 +223,6 @@ class AsyncFetcher:
                 raise ValueError(msg)
             # assert self.client is not None # give mypy a clue
             processed = await self.fetch_and_process(urls=urls, client=self.client)
-            if self.close_client_on_completion:
-                await self.client.aclose()
         return processed
 
     async def fetch_and_process(self, urls: Iterator[str], client):
