@@ -27,7 +27,12 @@ if TYPE_CHECKING:  # pragma: no cover
 
 from .range_utils import range_termini
 
-__all__ = ["byte_range_from_range_obj", "range_header", "PartialContentStatusError"]
+__all__ = [
+    "byte_range_from_range_obj",
+    "range_header",
+    "PartialContentStatusError",
+    "detect_header_value",
+]
 
 
 def byte_range_from_range_obj(rng: Range) -> str:
@@ -49,7 +54,7 @@ def byte_range_from_range_obj(rng: Range) -> str:
       for "the last zero bytes" i.e. an empty range request.
     """
     if rng.isempty():
-        byte_range = "-0"
+        byte_range = "0-"
     else:
         start_byte, end_byte = range_termini(rng)
         byte_range = f"{start_byte}-{end_byte}"
@@ -57,8 +62,8 @@ def byte_range_from_range_obj(rng: Range) -> str:
 
 
 def range_header(rng: Range) -> dict[str, str]:
-    # """Prepare a :class:`dict` to pass as a :mod:`httpx` request header
-    """Prepare a :class:`dict` to pass as a ``httpx`` request header
+    """
+    Prepare a :class:`dict` to pass as a ``httpx`` request header
     with a single key ``ranges`` whose value is the byte range.
 
     For example:
@@ -67,6 +72,10 @@ def range_header(rng: Range) -> dict[str, str]:
       >>> range_header(Range(0,2))
       {'range': 'bytes=0-1'}
 
+      >>> range_header(Range(0,0))
+      {'range': 'bytes=0-'}
+
+
     Args:
       rng : range of the bytes to be requested (0-based)
 
@@ -94,7 +103,7 @@ class PartialContentStatusError(Exception):
         self.response = response
 
 
-def detect_header_value(headers: dict, key: str):
+def detect_header_value(headers: dict, key: str, source: str = "Response"):
     """
     Detect a title case, lower case, or capitalised version of the given string.
     """
@@ -102,4 +111,4 @@ def detect_header_value(headers: dict, key: str):
     try:
         return next(headers.get(k) for k in variants if k in headers)
     except StopIteration:
-        raise KeyError(f"Response was missing '{key}' header")
+        raise KeyError(f"{source} was missing '{key}' header")
